==> james-project-3.7.6-source-release.zip: james-project/server/mailet/mailets/src/main/java/org/apache/james/transport/mailets/delivery/MailStore.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.transport.mailets.delivery;

import org.apache.james.core.MailAddress;
import org.apache.mailet.Mail;
import org.reactivestreams.Publisher;

public interface MailStore {
    String DELIVERY_PATH_PREFIX = "DeliveryPath_";

    Publisher<Void> storeMail(MailAddress recipient, Mail mail);
}

==> james-project-3.9.0-source-release.zip: james-project/server/mailet/mailets/src/main/java/org/apache/james/transport/mailets/delivery/MailStore.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.transport.mailets.delivery;

import org.apache.james.core.MailAddress;
import org.apache.james.mailbox.model.ComposedMessageId;
import org.apache.mailet.Mail;
import org.reactivestreams.Publisher;

public interface MailStore {
    Publisher<ComposedMessageId> storeMail(MailAddress recipient, Mail mail);
}
